@@ -3,6 +3,6 @@ countpattern2<-function (x)
 {
     intpatt<-apply(as.matrix(x),1,bin2int)
     intpatt<-intpatt+1
-    pat<-tabulate(intpatt,nb=2^ncol(as.matrix(x)))
+    pat<-tabulate(intpatt,nbins=2^ncol(as.matrix(x)))
     pat
 }
