@@ -214,3 +214,7 @@ cat('\n')
   cat('\n')
   invisible(x)
 }
+"BIC.pattNPML"<-
+function(object, ...){
+object$disparity + (length(c(na.omit(object$coefficients),object$masses))-1) * log(sum(object$data$y))
+}
